/**
 *
 *  Nettles 'n' stuff Effect
 *  @author Drakkos
 *  @started 31/03/2009
 *
 */
 

#include <effect.h>

/**
 *
 *  This is the method called when an effect is first applied to an 
 *  object.
 *
 *  @param        player          The object on which the effect is applied
 *  @param        args            Any arguments provided to the effect
 *  @param        id              A unique ID.  Don't worry about this
 *  @returns                      The argument of the effect
 *
 */
 
mixed beginning( object player, mixed args, int id ) {
  // Give the player a message to indicate the effect has been applied.
  tell_object (player, "Argh!  You must have put your hands in some "
    "stinging nettles.\n");
  // Do some initial damage to them based on the strength of the effect.
  player->adjust_hp (-1 * args);
  // Submit an effect event.  Every 20 seconds, the method damage_me
  // will be called on this object.  EE_CONTINUOUS ensures that this 
  // will happen regularly through an effect's lifetime.
  player->submit_ee( "damage_me", 20, EE_CONTINUOUS );
  // Submit an effect event to remove the effect.  EE_REMOVE triggers 
  // once and then deletes the effect from the player.
  player->submit_ee( 0, args, EE_REMOVE);
  return args;    
}

/**
 *
 *  Do some damage to the player.  Called as part of the effect event
 *  setup in beginning.
 *
 *  @param        player          The object on which the effect is applied
 *  @param        args            Any arguments provided to the effect
 *  @param        id              A unique ID.  Don't worry about this
 *
 */
 
void damage_me(object player, mixed args, int id ) {
  // Do some periodic damage to the object to which the effect is 
  // applied.
  player->adjust_hp (-1 * random (args));
  // Send them a delicious message.
  tell_object (player, "Oooh, that stings!\n");
}

/**
 *
 *  This is the method called when an effect is applied to an object
 *  that already has this effect active.
 *
 *  @param        player          The object on which the effect is applied
 *  @param        old_args        The argument of the existing effect
 *  @param        new_args        The argument of the effect being added
 *  @param        id              A unique ID.  Don't worry about this
 *  @returns                      The new argument of the effect
 *
 */
 
mixed merge_effect( object player, mixed old_args, mixed new_args, int id ) {
  // Find out how much time until the EE_REMOVE event occurs.
  int time_left = player->expected_tt();
    
  // Add the value of our new arguments to that.
  time_left += new_args;
  
  // Submit a new EE_REMOVE event.  This will overwrite the previous one.
  player->submit_ee (0, time_left, EE_REMOVE);
  
  // Now we impact on the strength of the effect.  We set the argument of 
  // the effect to be whatever the higher of the two values is.
  if (old_args > new_args) {
    return old_args;
  }
  return new_args;
}

/**
 *
 *  This is the method called when an effect is removed at any point.
 *
 *  @param        player          The object on which the effect is applied
 *  @param        args            Any arguments provided to the effect
 *  @param        id              A unique ID.  Don't worry about this
 *
 */
 
void end( object player, mixed args, int id ) {
  // Give them a message to indicate the effect is being removed.
  tell_object (player, "The stinging from the nettles subsides.\n");
} 

/**
 *
 *  The classification of the effect.  Used for effects_matching later on.
 *
 *  @string                      The classification of the effect
 *
 */
 
string query_classification() { 
  return "body.nettles";
}

/**
 *
 *  This is the method called when an effect is restarted, such as when 
 *  a player logs off and on.
 *
 *  @param        player          The object on which the effect is applied
 *  @param        args            Any arguments provided to the effect
 *  @param        id              A unique ID.  Don't worry about this
 *
 */
 
void restart( object player, mixed args ) {
  tell_object (player, "Argh!  You must have put your hands in some "
    "stinging nettles.\n");
}
